@@ -123,8 +123,8 @@ ccm = function( block,
   ccmReturn = CCM( pathIn          = "./",
                    dataFile        = "",
                    dataFrame       = dataFrame,
-                   pathOut         = "./",
-                   predictFile     = "",
+                   # pathOut         = "./", # Rcpp 20 param limit
+                   # predictFile     = "",   # Rcpp 20 param limit
                    E               = E, 
                    Tp              = tp,
                    knn             = knn,
@@ -137,6 +137,7 @@ ccm = function( block,
                    random          = random_libs,
                    replacement     = replace,
                    seed            = seed,
+                   embedded        = FALSE,
                    includeData     = includeData,
                    parameterList   = FALSE,
                    verbose         = verbose,
