@@ -36,8 +36,8 @@ void EmbedThread( EDM_Eval::WorkQueue &workQ,
                   int                  Tp,
                   int                  tau,
                   int                  exclusionRadius,
-                  std::string          colNames,
-                  std::string          targetName,
+                  std::string          columns,
+                  std::string          target,
                   bool                 embedded,
                   bool                 verbose,
                   std::vector<bool>    validLib );
@@ -54,8 +54,8 @@ void PredictIntervalThread( EDM_Eval::WorkQueue &workQ,
                             int                  E,
                             int                  tau,
                             int                  exclusionRadius,
-                            std::string          colNames,
-                            std::string          targetName,
+                            std::string          columns,
+                            std::string          target,
                             bool                 embedded,
                             bool                 verbose,
                             std::vector<bool>    validLib );
@@ -75,8 +75,8 @@ void SMapThread( EDM_Eval::WorkQueue   &workQ,
                  int                    knn,
                  int                    tau,
                  int                    exclusionRadius,
-                 std::string            colNames,
-                 std::string            targetName,
+                 std::string            columns,
+                 std::string            target,
                  bool                   embedded,
                  bool                   verbose,
                  std::vector<bool>      validLib );
@@ -96,8 +96,8 @@ DataFrame< double > EmbedDimension( std::string       pathIn,
                                     int               Tp,
                                     int               tau,
                                     int               exclusionRadius,
-                                    std::string       colNames,
-                                    std::string       targetName,
+                                    std::string       columns,
+                                    std::string       target,
                                     bool              embedded,
                                     bool              verbose,
                                     std::vector<bool> validLib,
@@ -115,8 +115,8 @@ DataFrame< double > EmbedDimension( std::string       pathIn,
                                               Tp,
                                               tau,
                                               exclusionRadius,
-                                              colNames,
-                                              targetName,
+                                              columns,
+                                              target,
                                               embedded,
                                               verbose,
                                               validLib,
@@ -137,8 +137,8 @@ DataFrame< double > EmbedDimension( DataFrame< double > & data,
                                     int                   Tp,
                                     int                   tau,
                                     int                   exclusionRadius,
-                                    std::string           colNames,
-                                    std::string           targetName,
+                                    std::string           columns,
+                                    std::string           target,
                                     bool                  embedded,
                                     bool                  verbose,
                                     std::vector<bool>     validLib,
@@ -172,8 +172,8 @@ DataFrame< double > EmbedDimension( DataFrame< double > & data,
                                         Tp,
                                         tau,
                                         exclusionRadius,
-                                        colNames,
-                                        targetName,
+                                        columns,
+                                        target,
                                         embedded,
                                         verbose,
                                         validLib ) );
@@ -216,8 +216,8 @@ void EmbedThread( EDM_Eval::WorkQueue & workQ,
                   int                   Tp,
                   int                   tau,
                   int                   exclusionRadius,
-                  std::string           colNames,
-                  std::string           targetName,
+                  std::string           columns,
+                  std::string           target,
                   bool                  embedded,
                   bool                  verbose,
                   std::vector<bool>     validLib )
@@ -245,8 +245,8 @@ void EmbedThread( EDM_Eval::WorkQueue & workQ,
                                        0,           // knn
                                        tau,
                                        exclusionRadius,
-                                       colNames,
-                                       targetName,
+                                       columns,
+                                       target,
                                        embedded,
                                        false,       // const_predict
                                        verbose,
@@ -293,8 +293,8 @@ DataFrame< double > PredictInterval( std::string       pathIn,
                                      int               E,
                                      int               tau,
                                      int               exclusionRadius,
-                                     std::string       colNames,
-                                     std::string       targetName,
+                                     std::string       columns,
+                                     std::string       target,
                                      bool              embedded,
                                      bool              verbose,
                                      std::vector<bool> validLib,
@@ -312,8 +312,8 @@ DataFrame< double > PredictInterval( std::string       pathIn,
                                                   E,
                                                   tau,
                                                   exclusionRadius,
-                                                  colNames,
-                                                  targetName,
+                                                  columns,
+                                                  target,
                                                   embedded,
                                                   verbose,
                                                   validLib,
@@ -334,8 +334,8 @@ DataFrame< double > PredictInterval( DataFrame< double > & data,
                                      int                   E,
                                      int                   tau,
                                      int                   exclusionRadius,
-                                     std::string           colNames,
-                                     std::string           targetName,
+                                     std::string           columns,
+                                     std::string           target,
                                      bool                  embedded,
                                      bool                  verbose,
                                      std::vector<bool>     validLib,
@@ -368,8 +368,8 @@ DataFrame< double > PredictInterval( DataFrame< double > & data,
                                         E,
                                         tau,
                                         exclusionRadius,
-                                        colNames,
-                                        targetName,
+                                        columns,
+                                        target,
                                         embedded,
                                         verbose,
                                         validLib ) );
@@ -412,8 +412,8 @@ void PredictIntervalThread( EDM_Eval::WorkQueue &workQ,
                             int                  E,
                             int                  tau,
                             int                  exclusionRadius,
-                            std::string          colNames,
-                            std::string          targetName,
+                            std::string          columns,
+                            std::string          target,
                             bool                 embedded,
                             bool                 verbose,
                             std::vector<bool>    validLib )
@@ -441,8 +441,8 @@ void PredictIntervalThread( EDM_Eval::WorkQueue &workQ,
                                        0,           // knn
                                        tau,
                                        exclusionRadius,
-                                       colNames,
-                                       targetName,
+                                       columns,
+                                       target,
                                        embedded,
                                        false,       // const_pred
                                        verbose,
@@ -492,8 +492,8 @@ DataFrame< double > PredictNonlinear( std::string       pathIn,
                                       int               knn,
                                       int               tau,
                                       int               exclusionRadius,
-                                      std::string       colNames,
-                                      std::string       targetName,
+                                      std::string       columns,
+                                      std::string       target,
                                       bool              embedded,
                                       bool              verbose,
                                       std::vector<bool> validLib,
@@ -513,8 +513,8 @@ DataFrame< double > PredictNonlinear( std::string       pathIn,
                                                       knn,
                                                       tau,
                                                       exclusionRadius,
-                                                      colNames,
-                                                      targetName,
+                                                      columns,
+                                                      target,
                                                       embedded,
                                                       verbose,
                                                       validLib,
@@ -537,8 +537,8 @@ DataFrame< double > PredictNonlinear( DataFrame< double > & data,
                                       int                   knn,
                                       int                   tau,
                                       int                   exclusionRadius,
-                                      std::string           colNames,
-                                      std::string           targetName,
+                                      std::string           columns,
+                                      std::string           target,
                                       bool                  embedded,
                                       bool                  verbose,
                                       std::vector<bool>     validLib,
@@ -596,8 +596,8 @@ DataFrame< double > PredictNonlinear( DataFrame< double > & data,
                                         knn,
                                         tau,
                                         exclusionRadius,
-                                        colNames,
-                                        targetName,
+                                        columns,
+                                        target,
                                         embedded,
                                         verbose,
                                         validLib ) );
@@ -643,8 +643,8 @@ void SMapThread( EDM_Eval::WorkQueue   &workQ,
                  int                    knn,
                  int                    tau,
                  int                    exclusionRadius,
-                 std::string            colNames,
-                 std::string            targetName,
+                 std::string            columns,
+                 std::string            target,
                  bool                   embedded,
                  bool                   verbose,
                  std::vector<bool>      validLib )
@@ -672,8 +672,8 @@ void SMapThread( EDM_Eval::WorkQueue   &workQ,
                                  tau,
                                  theta,
                                  exclusionRadius,
-                                 colNames,
-                                 targetName,
+                                 columns,
+                                 target,
                                  "",        // smapFile
                                  "",        // derivatives
                                  embedded,
